<?php

namespace SlotDb\Cli\Command\Slot;

use SlotDb\Client\SlotDbClient;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Helper\Table;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

#[AsCommand(name:"slot:find", aliases:[ "find" ], description:"Find all slots, or slots matching conditions")]
class SlotFindCommand extends Command
{
    public function __construct(
        private readonly SlotDbClient $client
    )
    {
        parent::__construct();
    }

    protected function configure()
    {
        $this
            ->addArgument("where", InputArgument::IS_ARRAY, "Conditions that are ANDed")
            ;
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {

        $wheres = $input->getArgument("where");

        $whereConds = [];
        foreach ($wheres as $where) {
            if (preg_match('<^(.+?)(=|\<=|\>=|\<|\>)(.+?)$>', $where, $match)) {
                $c = $match[2];
                if ($c == '=') $c = '';
                $whereConds[$match[1]] = sprintf("%s%s", $c, $match[3]);
            }
        }

        $slots = $this->client->findSlots($whereConds);

        $keys = [];
        foreach ($slots as $slot) {
            $keys = array_merge($keys, array_keys($slot));
        }
        $keys = array_unique($keys);

        $table = new Table($output);
        $table->setHeaders($keys);
        $table->setStyle('box');
        foreach ($slots as $slot) {
            $row = [];
            foreach ($keys as $key) {
                $row[] = isset($slot[$key]) ? json_encode($slot[$key]) : null;
            }
            $table->addRow($row);
        }

        $table->render();

        return self::SUCCESS;
    }
}
