<?php

namespace SlotDb\Cli\Command\Slot;

use SlotDb\Client\SlotDbClient;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

#[AsCommand(name:"slot:query", aliases:[ "query" ], description:"Query a slot and its properties")]
class SlotQueryCommand extends Command
{
    public function __construct(
        private readonly SlotDbClient $client
    )
    {
        parent::__construct();
    }

    protected function configure()
    {
        $this
            ->addArgument("slot", InputArgument::REQUIRED, "Slot ID")
            ;
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {

        $slotId = $input->getArgument("slot");
        $slot = $this->client->querySlot($slotId);

        $len = 2 + max(array_map(mb_strlen(...), array_keys($slot)));
        foreach ($slot as $k=>$v) {
            $output->writeln(
                sprintf(
                    str_starts_with($k,"_")
                    ? "<fg=green>%{$len}s</>: <fg=gray>%s</>"
                    : "<fg=green;options=bold>%{$len}s</>: <fg=yellow>%s</>",
                    $k, json_encode($v)
                )
            );
        }

        return self::SUCCESS;
    }
}
